@@ -279,7 +279,9 @@ fxt_blockev_t fxt_blockev_enter(fxt_t fxt);
 /* get next event in the event stream */
 int fxt_next_ev(fxt_blockev_t evs, int ev_type, struct fxt_ev *ev);
 /* rewind within the event stream */
-int fxt_rewind(fxt_blockev_t fxt);
+int fxt_rewind(fxt_blockev_t evs);
+/* close event stream */
+void fxt_blockev_leave(fxt_blockev_t evs);
 
 // fonctions avances: savoir le type d'vnement et en extraire des infos:
 //
